@@ -27,56 +27,68 @@
 # Config variables
 DEBUG = 1
 
+# daemon mode vars
+DEF_USER = ("gsharov", 26096)  # default name: (username, uid)
+DEF_PIPELINE = "Relion"  # default pipeline: Relion or Scipion
+DEF_SOFTWARE = "EPU"  # default software: EPU or SerialEM
+DEF_PREFIX = "lmb_"  # found metadata folder name should start with this prefix
+
 # path to EPU session or folder with SerialEM mdoc files
-METADATA_PATH = "/home/azazello/soft/MDCatch/mdcatch/Metadata-examples"
+METADATA_PATH = "/mnt/MetaData/Krios1/Falcon/OTFP"
+#METADATA_PATH = "/home/azazello/soft/MDCatch/mdcatch/Metadata-examples"
 
 # path where Relion projects are created
-PROJECT_PATH = "/work/gsharov/tmp"
+PROJECT_PATH = "/cephfs"
 
 # Folder with Relion 3.1 schedules
-SCHEDULE_PATH = "/home/azazello/soft/MDCatch/mdcatch/Schedules"
+SCHEDULE_PATH = "/home/gsharov/soft/MDCatch/mdcatch/Schedules"
 
 # Scipion pre-processing template and output file
-JSON_TEMPLATE = "/home/azazello/soft/MDCatch/mdcatch/template.json"
+JSON_TEMPLATE = "/home/gsharov/soft/MDCatch/mdcatch/template.json"
 JSON_PATH = "workflow.json"
 
-# EPU 2.6.1 patterns
-EPU_MOVIES_PATH = "Images-Disc*/GridSquare_*/Data/FoilHole_*.mrc"
-PATTERN_EPU = "FoilHole_[0-9]{6,8}_Data_[0-9]{6,8}_[0-9]{6,8}_[0-9]{8}_[0-9]{4,6}.(xml|mrc)$"
-GAIN_DICT = {'K2': "FoilHole_[0-9]{6,8}_Data_[0-9]{6,8}_[0-9]{6,8}_[0-9]{8}_[0-9]{4,6}-gain-ref.MRC$",
-             'K3': "FoilHole_[0-9]{6,8}_Data_[0-9]{6,8}_[0-9]{6,8}_[0-9]{8}_[0-9]{4,6}_gain.tiff$"
+# main dictionary
+# instrumentID: [name, Cs, TFS camera, Gatan camera]
+SCOPE_DICT = {'3299': ['Krios1', 2.7, 'Falcon', 'K2'],
+              '3413': ['Krios2', 2.7, 'Falcon', 'K2'],
+              '3593': ['Krios3', 2.7, 'Falcon', 'K3'],
+              '9952833': ['Glacios', 2.7, 'Falcon', None]
+              }
+
+###############################################################################
+# EPU 2.4+ patterns
+EPU_MOVIES_DICT = {'Falcon': "Images-Disc*/GridSquare_*/Data/FoilHole_*_Data_*_Fractions.mrc",
+                   'K2': "Images-Disc*/GridSquare_*/Data/FoilHole_*_Data_*.mrc",
+                   'K3': "Images-Disc*/GridSquare_*/Data/FoilHole_*_Data_*_fractions.tiff"
+                   }
+GAIN_DICT = {'K2': "FoilHole_*_Data_*-gain-ref.MRC",
+             'K3': "FoilHole_*_Data_*_gain.tiff"
              }
 
+# change the pattern below if you want to parse movie sums mrc instead
+PATTERN_EPU = "Images-Disc*/GridSquare_*/Data/FoilHole_*_Data_*.xml"
+
+###############################################################################
 # SerialEM patterns
 PATTERN_MDOC = ".{1,}\.tif\.mdoc$"
 REGEX_MDOC_VAR = "(?P<var>[a-zA-Z0-9]+?) = (?P<value>(.*))"
 
-# default particle size for Relion LoG picker
-part_size_short = 150
-part_size_long = 180
-
-# instrumentID: [name, Cs, TFS camera, Gatan camera]
-SCOPE_DICT = {'3299': ['Krios1', 2.7, 'Falcon3', 'K2'],
-              '3413': ['Krios2', 2.7, 'Falcon3', 'K2'],
-              '3593': ['Krios3', 2.7, 'Falcon3', 'K3'],
-              '9952833': ['Glacios', 2.7, 'Falcon3', None]
-              }
-
 # path to MTF files for Relion (300 kV only)
 # examples: Name-count, Name-linear or Name,
-# where Name should match the camera name in SCOPE_DICT
+# camera names should match SCOPE_DICT
 MTF_DICT = {
-    'Falcon3-count': '/home/gsharov/soft/MTFs/mtf_falcon3EC_300kV.star',
-    'Falcon3-linear': '/home/gsharov/soft/MTFs/mtf_falcon2_300kV.star',
+    'Falcon-count': '/home/gsharov/soft/MTFs/mtf_falcon3EC_300kV.star',
+    'Falcon-linear': '/home/gsharov/soft/MTFs/mtf_falcon2_300kV.star',
     'K2': '/home/gsharov/soft/MTFs/mtf_k2_300kV.star',
     'K3': '/home/gsharov/soft/MTFs/mtf_K3_300kv_nocds.star'
 }
 
 # path to raw movies folder depending on camera name
-# example: /mnt/Krios1/Data/Falcon3/
+# example: /mnt/Data/Krios3/K3/
+# scope and camera names should match SCOPE_DICT
 MOVIE_PATH_DICT = {
-    'EF-CCD': '/mnt/%s/Data/%s/',
-    'BM-Falcon': '/mnt/%s/Data/%s/'
+    'EF-CCD': '/mnt/Data/%s/%s/',
+    'BM-Falcon': '/mnt/Data/%s/%s/'
 }
 
 # SerialEM mdoc vars to parse
@@ -90,10 +102,9 @@ SERIALEM_PARAMS = [
     'Binning',
     'TargetDefocus',
     'NumSubFrames',
-    #'DateTime',
+    # 'DateTime',
     'DefectFile',
     'GainReference',
-
     # optional vars below can be added to mdoc using "AddToNextFrameStackMdoc key value"
     'OpticalGroup',
     'PhasePlateInserted',
@@ -101,10 +112,10 @@ SERIALEM_PARAMS = [
     'Beamtilt'
 ]
 
-# error message for path selection
+# help message for path selection
 help_message = """Select the following folder:\n\n
-   1) EPU: the EPU session folder on /mnt/Krios1/Metadata
+   For EPU: the EPU session folder on /mnt/MetaData/
    with Images-DiscX folder inside.\n
    OR\n
-   2) SerialEM: the folder on /mnt/Krios1/Data/K2/ that
+   For SerialEM: the folder on /mnt/Data/ that
    contains tif movies and mdoc files.\n"""
