@@ -25,28 +25,29 @@
 # *
 # **************************************************************************
 
+import os
+import sys
 from PyQt5.QtWidgets import (QGridLayout, QLabel, QMessageBox,
                              QHBoxLayout, QVBoxLayout, QRadioButton,
-                             QPushButton, QWizard, QGroupBox, QSpinBox,
+                             QPushButton, QWizard, QGroupBox,
                              QSizePolicy, QLineEdit, QFileDialog,
                              QCheckBox, QApplication, QWizardPage,
                              QButtonGroup)
 from PyQt5.QtCore import Qt
-import sys
 
+from .config import *
 from .parser import Parser
-from .schedule import *
-
+from .schedule import setupRelion, setupScipion
 
 
 class App(QWizard):
     model = Parser()
 
     def __init__(self, parent=None):
-        super(App, self).__init__(parent)
-        self.title = 'MDCatch v0.9.5 - metadata parser'
+        super(App, self).__init__(parent, flags=Qt.WindowFlags())
+        self.title = 'MDCatch v0.9.7 - metadata parser'
         self.width = 640
-        self.height = 480
+        self.height = 320
         self.initUI()
 
     def initUI(self):
@@ -57,7 +58,7 @@ class App(QWizard):
         self.button(QWizard.BackButton).clicked.connect(self.page1.reset)
         self.button(QWizard.FinishButton).clicked.connect(self.page2.onFinish)
         self.setWindowTitle(self.title)
-        self.setWindowFlags(self.windowFlags() | Qt.CustomizeWindowHint)
+        # remove Help button from the window
         self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
         self.resize(self.width, self.height)
 
@@ -83,22 +84,17 @@ class Page1(QWizardPage):
         self.mainLayout = QGridLayout()
         self.mainLayout.addLayout(self.group1(), 0, 0)
         self.mainLayout.addLayout(self.group2(), 0, 1)
-        self.mainLayout.addLayout(self.group3(), 1, 1)
         self.setLayout(self.mainLayout)
 
     def group1(self):
         vbox = QVBoxLayout()
         label1 = QLabel('Software')
         label2 = QLabel('Path')
-        label3 = QLabel('Particle diameter (A)')
-        label4 = QLabel('Launch pipeline in')
-        label5 = QLabel('LMB username')
+        label3 = QLabel('Run pipeline in')
 
-        vbox.addWidget(label1)
-        vbox.addWidget(label2)
-        vbox.addWidget(label3)
-        vbox.addWidget(label4)
-        vbox.addWidget(label5)
+        vbox.addWidget(label1, alignment=Qt.Alignment())
+        vbox.addWidget(label2, alignment=Qt.Alignment())
+        vbox.addWidget(label3, alignment=Qt.Alignment())
 
         return vbox
 
@@ -110,95 +106,49 @@ class Page1(QWizardPage):
         hbox1.setAlignment(Qt.AlignLeft)
         btgroup1 = QButtonGroup()
 
-        b1 = self.addRadioButton("EPU", default=True)
-        b2 = self.addRadioButton("SerialEM")
+        b1 = self.addRadioButton("EPU", default=DEF_SOFTWARE=="EPU")
+        b2 = self.addRadioButton("SerialEM", default=DEF_SOFTWARE=="SerialEM")
 
         btgroup1.addButton(b1)
         btgroup1.addButton(b2)
         btgroup1.buttonClicked.connect(lambda: self.updSoftware(btgroup1))
-        hbox1.addWidget(b1)
-        hbox1.addWidget(b2)
+        hbox1.addWidget(b1, alignment=Qt.Alignment())
+        hbox1.addWidget(b2, alignment=Qt.Alignment())
         grid.addLayout(hbox1)
 
         # path box
         hbox2 = QHBoxLayout()
         self.rawPath = QLineEdit()
+        self.rawPath.setMinimumWidth(300)
         self.rawPath.setReadOnly(True)
         self.rawPath.setText(METADATA_PATH)
+        self.rawPath.setToolTip(help_message)
 
         b3 = QPushButton('Browse')
+        b3.setToolTip(help_message)
         b3.clicked.connect(lambda: self.browseSlot(self.rawPath))
-        b4 = QPushButton('?')
-        b4.setFixedSize(20, 25)
-        b4.clicked.connect(self.helpSlot)
 
-        hbox2.addWidget(self.rawPath)
-        hbox2.addWidget(b3)
-        hbox2.addWidget(b4)
+        hbox2.addWidget(self.rawPath, alignment=Qt.Alignment())
+        hbox2.addWidget(b3, alignment=Qt.Alignment())
         grid.addLayout(hbox2)
 
-        # size box
-        hbox3 = QHBoxLayout()
-        labelSizeMin = QLabel('from')
-        hbox3.addWidget(labelSizeMin)
-
-        self.size_short = QSpinBox()
-        self.size_short.setRange(10, 9999)
-        self.size_short.setValue(part_size_short)
-        self.size_short.setFixedSize(60, 25)
-        hbox3.addWidget(self.size_short)
-
-        labelSizeMax = QLabel('to')
-        hbox3.addWidget(labelSizeMax)
-
-        self.size_long = QSpinBox()
-        self.size_long.setRange(10, 9999)
-        self.size_long.setValue(part_size_long)
-        self.size_long.setFixedSize(60, 25)
-        hbox3.addWidget(self.size_long)
-        hbox3.setAlignment(Qt.AlignLeft)
-        grid.addLayout(hbox3)
-
         # pipeline
-        hbox4 = QHBoxLayout()
-        hbox4.setAlignment(Qt.AlignLeft)
+        hbox3 = QHBoxLayout()
+        hbox3.setAlignment(Qt.AlignLeft)
         btgroup2 = QButtonGroup()
 
-        b5 = self.addRadioButton("Relion", default=True)
-        b6 = self.addRadioButton("Scipion")
+        b4 = self.addRadioButton("Relion", default=DEF_PIPELINE=="Relion")
+        b5 = self.addRadioButton("Scipion", default=DEF_PIPELINE=="Scipion")
 
+        btgroup2.addButton(b4)
         btgroup2.addButton(b5)
-        btgroup2.addButton(b6)
         btgroup2.buttonClicked.connect(lambda: self.updPipeline(btgroup2))
-        hbox4.addWidget(b5)
-        hbox4.addWidget(b6)
-        grid.addLayout(hbox4)
-
-        # username
-        hbox5 = QHBoxLayout()
-        hbox5.setAlignment(Qt.AlignLeft)
-        self.username = QLineEdit()
-        self.username.setFixedSize(200, 25)
-
-        self.b7 = QPushButton('Check!')
-        self.b7.setFixedSize(70, 25)
-        self.b7.clicked.connect(lambda: self.checkLogin(self.username.text()))
-
-        hbox5.addWidget(self.username)
-        hbox5.addWidget(self.b7)
-        grid.addLayout(hbox5)
+        hbox3.addWidget(b4, alignment=Qt.Alignment())
+        hbox3.addWidget(b5, alignment=Qt.Alignment())
+        grid.addLayout(hbox3)
 
         return grid
 
-    def group3(self):
-        vbox = QVBoxLayout()
-        self.label6 = QLabel('')
-        self.label6.setVisible(False)
-
-        vbox.addWidget(self.label6)
-
-        return vbox
-
     def updSoftware(self, btgroup):
         bt = btgroup.checkedButton()
         App.model.setSoftware(bt.text())
@@ -208,11 +158,11 @@ class Page1(QWizardPage):
         App.model.setPipeline(bt.text())
 
     def browseSlot(self, var):
-        # called when a user press Browse
+        # called when "Browse" is pressed
         folder = METADATA_PATH if var.text() is None else var.text()
         path = QFileDialog.getExistingDirectory(self, "Select Directory",
                                                 folder,
-                                                QFileDialog.ShowDirsOnly)
+                                                options=QFileDialog.ShowDirsOnly)
         if path:
             self.refreshPath(path)
 
@@ -226,43 +176,16 @@ class Page1(QWizardPage):
         App.showDialog("Help", help_message, 'help')
         return
 
-    def checkLogin(self, login):
-        # match username with NIS database
-        cmd = "/usr/bin/ypmatch %s passwd" % login
-        try:
-            res = subprocess.check_output(cmd.split())
-        except subprocess.CalledProcessError:
-            App.showDialog("ERROR", "Username %s not found!" % login)
-            return False
-        except FileNotFoundError:
-            App.showDialog("ERROR", "Command %s not found!" % cmd.split()[0])
-            return False
-
-        res = str(res)
-        uid, gid = res.split(':')[2], res.split(':')[3]
-        self.label6.setVisible(True)
-        self.label6.setStyleSheet('color: green')
-        self.label6.setText('Check OK: UID=%s, GID=%s' % (uid, gid))
-        App.model.setUser(login, uid, gid)
-        return True
-
     def validatePage(self):
         # Next is pressed, returns True or False
-        App.model.setSizes(self.size_short.text(), self.size_long.text())
         if App.model.getMdPath() is None:
             App.model.setMdPath(METADATA_PATH)
 
-        # prevent Check button bypass
-        usrchk = self.checkLogin(self.username.text())
-        if not usrchk:
-            return False
-
         if DEBUG:
             print("\n\nInput params: ",
                   [App.model.getSoftware(),
                    App.model.getMdPath(),
                    App.model.getUser(),
-                   App.model.getSizes(),
                    App.model.getPipeline()])
 
         prog = App.model.getSoftware()
@@ -288,7 +211,6 @@ class Page1(QWizardPage):
 
         sizePolicy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Preferred)
         rb.setSizePolicy(sizePolicy)
-
         return rb
 
 
@@ -298,8 +220,6 @@ class Page2(QWizardPage):
         self.mainLayout = QGridLayout()
         self.mainLayout.addWidget(self.group1(), 0, 0)
         self.mainLayout.addWidget(self.group2(), 0, 1)
-        self.mainLayout.addWidget(self.group3(), 1, 0)
-        self.mainLayout.addWidget(self.group4(), 1, 1)
         self.setLayout(self.mainLayout)
 
     def initializePage(self):
@@ -313,10 +233,8 @@ class Page2(QWizardPage):
         else:  # SerialEM
             App.model.parseImgMdoc(fnList)
 
-        acqDict['PtclSizeShort'], acqDict['PtclSizeLong'] = App.model.getSizes()
         App.model.calcDose()
-        App.model.calcBox()
-        App.model.guessDataDir(fnList)
+        App.model.guessDataDir()
 
         self.setSubTitle("Found the following metadata from %s session:" % prog)
 
@@ -343,13 +261,9 @@ class Page2(QWizardPage):
         self.dosepf.setText(str(dosepf))
         self.gain.setText(os.path.basename(acqDict['GainReference']))
         self.defects.setText(os.path.basename(acqDict['DefectFile']))
-        self.box.setText(acqDict['BoxSize'])
-        self.mask.setText(acqDict['MaskSize'])
-        self.box2.setText(acqDict['BoxSizeSmall'])
 
     def group1(self):
         groupBox = QGroupBox("Microscope")
-
         name = QLabel("Name")
         kv = QLabel("Voltage (kV)")
         cs = QLabel("Cs (mm)")
@@ -360,7 +274,7 @@ class Page2(QWizardPage):
         self.kv = QLabel()
         self.cs = QLabel()
         self.vpp = QCheckBox()
-        self.px = self.addLine(50, 20, 5, Qt.AlignRight)
+        self.px = self.addLine(50, 5, Qt.AlignRight)
 
         vbox = QGridLayout()
         for num, i in enumerate([name, kv, cs, px, vpp]):
@@ -371,12 +285,10 @@ class Page2(QWizardPage):
             vbox.addWidget(i, num, 1)
 
         groupBox.setLayout(vbox)
-
         return groupBox
 
     def group2(self):
         groupBox = QGroupBox("Detector")
-
         name2 = QLabel("Name")
         mode = QLabel("Mode")
         time = QLabel("Exposure time (s)")
@@ -391,7 +303,7 @@ class Page2(QWizardPage):
         self.frames = QLabel()
         self.gain = QLabel()
         self.defects = QLabel()
-        self.dosepf = self.addLine(50, 20, 4, Qt.AlignRight)
+        self.dosepf = self.addLine(50, 5, Qt.AlignRight)
 
         vbox = QGridLayout()
         for num, i in enumerate([name2, mode, time, frames,
@@ -405,44 +317,6 @@ class Page2(QWizardPage):
             vbox.addWidget(i, num, 1)
 
         groupBox.setLayout(vbox)
-
-        return groupBox
-
-    def group3(self):
-        groupBox = QGroupBox("Recommended options")
-
-        box = QLabel("Box size (px)")
-        mask = QLabel("Mask size (px)")
-        box2 = QLabel("Downscale to (px)")
-
-        self.box = self.addLine(50, 20, 4, Qt.AlignRight)
-        self.mask = self.addLine(50, 20, 4, Qt.AlignRight)
-        self.box2 = self.addLine(50, 20, 4, Qt.AlignRight)
-
-        vbox = QGridLayout()
-        for num, i in enumerate([box, mask, box2]):
-            vbox.addWidget(i, num, 0)
-
-        for num, i in enumerate([self.box, self.mask,
-                                 self.box2]):
-            vbox.addWidget(i, num, 1)
-
-        groupBox.setLayout(vbox)
-
-        return groupBox
-
-    def group4(self):
-        groupBox = QGroupBox("Preprocessing")
-
-        self.runCtf = QRadioButton("Stop after CTF estimation?")
-        self.runCl2d = QRadioButton("Do 2D classification?")
-        self.runCl2d.setChecked(True)
-
-        hbox = QGridLayout()
-        hbox.addWidget(self.runCtf, 0, 0)
-        hbox.addWidget(self.runCl2d, 1, 0)
-        groupBox.setLayout(hbox)
-
         return groupBox
 
     def onFinish(self):
@@ -451,10 +325,6 @@ class Page2(QWizardPage):
         App.model.acqDict['DosePerFrame'] = self.dosepf.text()
         App.model.acqDict['PixelSpacing'] = self.px.text()
         App.model.acqDict['PhasePlateUsed'] = self.vpp.isChecked()
-        App.model.acqDict['NoCl2D'] = self.runCtf.isChecked()
-        App.model.acqDict['BoxSize'] = self.box.text()
-        App.model.acqDict['MaskSize'] = self.mask.text()
-        App.model.acqDict['BoxSizeSmall'] = self.box2.text()
 
         if DEBUG:
             print("\nFinal parameters:\n")
@@ -467,18 +337,31 @@ class Page2(QWizardPage):
         else:
             setupScipion(App.model.acqDict)
 
-    def addLine(self, sizex, sizey, length, align):
+    def addLine(self, size, length, align):
         line = QLineEdit()
-        line.setFixedSize(sizex, sizey)
+        line.setMinimumWidth(size)
+        line.setMaximumWidth(size)
         line.setMaxLength(length)
         line.setAlignment(align)
-
         return line
 
 
 def main():
-    app = QApplication(sys.argv)
-    app.setStyle('Fusion')
-    wizard = App()
-    wizard.show()
-    sys.exit(app.exec_())
+    args = sys.argv
+    help = "Usage: mdcatch [--watch]\nBy default starts a GUI, "\
+           "use '--watch' for daemon mode. It will watch METADATA_PATH folder."
+    if len(args) > 1:
+        if args[1] in ['-h', '--help']:
+            print(help)
+        elif args[1] == '--watch':
+            from .watcher import WatchDog
+            watch = WatchDog()
+            watch.start_daemon(METADATA_PATH)
+        else:
+            print("Unrecognized arguments.\n%s" % help)
+    else:
+        app = QApplication(sys.argv)
+        app.setStyle('Fusion')
+        wizard = App()
+        wizard.show()
+        sys.exit(app.exec_())
